@@ -60,7 +60,7 @@ def find_package_manager_files(directory, purl):
     purl = PackageURL.from_string(purl)
     package_type = purl.to_dict()["type"]
     package_manager_files = {
-        "pypi": ["requirements.txt", "Pipfile", "setup.py", "pyproject.toml"],
+        "pypi": ["requirements.txt", "Pipfile", "pyproject.toml"],
         "maven": ["pom.xml", "build.gradle", "build.gradle.kts"],
         "npm": ["package.json", "package-lock.json", "yarn.lock"],
         "golang": ["go.mod", "go.sum"],
@@ -175,12 +175,12 @@ class ExtractPackageManagerFile(Step):
                 found_src_files = find_package_manager_files(Path.cwd(), purl)
                 if len(found_src_files) > 1:
                     logger.info(
-                        f"{len(found_src_files)} package manager files found in the current working directory. Use the package_manager_file argument to specify the one to update."
+                        f"{len(found_src_files)} package manager files found in the current working directory for {purl}. Use the package_manager_file argument to specify the one to update."
                     )
                     continue
                 elif len(found_src_files) == 0:
                     logger.info(
-                        "No package manager files found in the current working directory. Use the package_manager_file argument to specify the file."
+                        f"No package manager files found in the current working directory for {purl}. Use the package_manager_file argument to specify the file."
                     )
                     continue
                 else:
@@ -196,16 +196,19 @@ class ExtractPackageManagerFile(Step):
         # Process each vulnerabiility in SBOM VDR data
         purl_list = []
         for vul in self.sbom_vdr_values.get("vulnerabilities", []):
+            severity = ""
             for rating in vul.get("ratings", []):
                 severity = rating.get("severity", "")
 
-            if SEVERITY_LEVELS.get(severity.lower()) < self.severity_threshold_level:
+            if severity != "" and SEVERITY_LEVELS.get(severity.lower(), 9999) < self.severity_threshold_level:
                 continue
 
+            ref = ""
+            fixed_version = None
+            vuln_version = ""
             for affect in vul.get("affects", []):
                 ref = affect.get("ref", "")
                 src_file = purl_to_srcfile.get(ref, "")
-                fixed_version = None
 
                 for version in affect.get("versions", []):
                     if version.get("status", "") == "affected":
